pilas.motores.motor_qt.CanvasWidget

Package pilas :: Package motores :: Module motor_qt :: Class CanvasWidget |
[hide private]
[frames] | no frames]

# Class CanvasWidget

source code

    PyQt4.QtGui.QWidget --+
                          |
                         CanvasWidget

Instance Methods | [hide private]
__init__(self, motor, lista_actores, ancho, alto, gestor_escenas, permitir_depuracion, rendimiento) | source code
resize_to(self, w, h) | source code
paintEvent(self, event) | source code
timerEvent(self, event) | source code
_realizar_actualizacion_logica(self) | source code
_actualizar_escena(self) | source code
_actualizar_eventos_y_actores(self) | source code
mouseMoveEvent(self, e) | source code
keyPressEvent(self, event) | source code
keyReleaseEvent(self, event) | source code
wheelEvent(self, e) | source code
mousePressEvent(self, e) | source code
mouseReleaseEvent(self, e) | source code
_obtener_codigo_de_tecla_normalizado(self, tecla_qt) | source code
pantalla_completa(self) | source code
pantalla_modo_ventana(self) | source code
esta_en_pantalla_completa(self) | source code
alternar_pausa(self) | source code
avanzar_un_solo_cuadro_de_animacion(self, evento) | source code
alternar_pantalla_completa(self) Permite cambiar el modo de video. | source code

Method Details | [hide private]

### alternar_pantalla_completa(self) | source code
Permite cambiar el modo de video. Si está en modo ventana, pasa a pantalla completa y viceversa.